@@ -253,8 +253,13 @@ async sub instantiatePlugin_p {
     my $name = shift;
     my $args = shift;
     my $user = $self->user;
-    my $plugin = await $self->config->instantiatePlugin_p($name,$user,$args);
-    $plugin->log($self->log);
+    my $plugin;
+    try {
+        $plugin = await $self->config->instantiatePlugin_p($name,$user,$args);
+        $plugin->log($self->log);
+    } catch($error) {
+        $self->log->warn($error);
+    }
     return $plugin;
 }
 
